@@ -1,25 +1,7 @@
-/*
- * Biloba
- * Copyright (C) 2004-2005 Guillaume Demougeot, Colin Leroy
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- */
-
 #include <unistd.h>
 #include <stdio.h>
 #include <sys/types.h>
+#include <errno.h>
 #ifndef __MINGW32__
 #include <sys/socket.h>
 #include <netinet/in.h>
@@ -84,7 +66,7 @@ int read_msg(int fd, void *buf, unsigned char avail, unsigned char *len)
 	
 	do {
 		readlen = recv(fd, buf, rem, MSG_NOSIGNAL);
-		if (readlen < 0) {
+		if (readlen < 1) {
 			printf("recv error (2): %d\n", readlen);
 			*len = 0;
 			return -1;
