@@ -1,6 +1,6 @@
 /*
  * Biloba
- * Copyright (C) 2004-2005 Guillaume Demougeot, Colin Leroy
+ * Copyright (C) 2004-2008 Guillaume Demougeot, Colin Leroy
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -86,25 +86,41 @@ static SDL_Surface *i_lfr = NULL, *i_len = NULL, *i_les = NULL;
 
 #define GAMENAME_MIN_X (50)
 #define GAMENAME_MAX_X (GAMENAME_MIN_X+350)
+#ifndef MAEMO
 #define GAMENAME_MIN_Y (400)
+#else
+#define GAMENAME_MIN_Y (360)
+#endif
 #define GAMENAME_MAX_Y (GAMENAME_MIN_Y+50)
 #define IN_GAMENAME(x,y) is_in_box(x,y,GAMENAME_MIN_X,GAMENAME_MIN_Y,GAMENAME_MAX_X,GAMENAME_MAX_Y)
 
 #define CREATEGAME_MIN_X (50)
 #define CREATEGAME_MAX_X (CREATEGAME_MIN_X+200)
+#ifndef MAEMO
 #define CREATEGAME_MIN_Y (500)
+#else
+#define CREATEGAME_MIN_Y (420)
+#endif
 #define CREATEGAME_MAX_Y (CREATEGAME_MIN_Y+50)
 #define IN_CREATEGAME(x,y) is_in_box(x,y,CREATEGAME_MIN_X,CREATEGAME_MIN_Y,CREATEGAME_MAX_X,CREATEGAME_MAX_Y)
 
 #define JOINGAME_MIN_X (300)
 #define JOINGAME_MAX_X (JOINGAME_MIN_X+200)
+#ifndef MAEMO
 #define JOINGAME_MIN_Y (500)
+#else
+#define JOINGAME_MIN_Y (420)
+#endif
 #define JOINGAME_MAX_Y (JOINGAME_MIN_Y+50)
 #define IN_JOINGAME(x,y) is_in_box(x,y,JOINGAME_MIN_X,JOINGAME_MIN_Y,JOINGAME_MAX_X,JOINGAME_MAX_Y)
 
 #define START_MIN_X (550)
 #define START_MAX_X (START_MIN_X+200)
+#ifndef MAEMO
 #define START_MIN_Y (500)
+#else
+#define START_MIN_Y (420)
+#endif
 #define START_MAX_Y (START_MIN_Y+50)
 #define IN_START(x,y) is_in_box(x,y,START_MIN_X,START_MIN_Y,START_MAX_X,START_MAX_Y)
 
@@ -140,7 +156,7 @@ static SDL_Surface *i_lfr = NULL, *i_len = NULL, *i_les = NULL;
 
 #define GAMELIST_MIN_X(i) (500)
 #define GAMELIST_MAX_X(i) (GAMELIST_MIN_X(i)+200)
-#define GAMELIST_MIN_Y(i) (200 + (40*(i)))
+#define GAMELIST_MIN_Y(i) (NETGAMES_MAX_Y + 1 + (40*(i)))
 #define GAMELIST_MAX_Y(i) (GAMELIST_MIN_Y(i)+40)
 #define IN_GAMELIST(i,x,y) is_in_box(x,y,GAMELIST_MIN_X(i),GAMELIST_MIN_Y(i),GAMELIST_MAX_X(i),GAMELIST_MAX_Y(i))
 
@@ -350,7 +366,7 @@ choose_again:
 				strcat(player_name[i-1], s_nump);
 			}
 			draw_message_with_update(player_name[i-1], 4 + PLAYERNAME_MIN_X(i), 
-					4 + PLAYERNAME_MIN_Y(i),
+					8 + PLAYERNAME_MIN_Y(i),
 					(player_edit == i), FALSE);
 			
 			if ((network_create || network_join) && player_type[i-1] != INPUT_LOCAL) {
@@ -366,7 +382,7 @@ choose_again:
 				strcpy(gamename,get_msg(M_NEWGAME));
 			}
 			draw_message_with_update(gamename,GAMENAME_MIN_X + 110, 
-					8 + GAMENAME_MIN_Y,
+					7 + GAMENAME_MIN_Y,
 					gamename_edit, FALSE);
 		} 
 		
@@ -424,7 +440,7 @@ choose_again:
 				key += 'A' - 'a';
 			}
 
-			if (key == SDLK_RETURN) {
+			if (key == SDLK_RETURN || key == SDLK_KP_ENTER || key == SDLK_ESCAPE) {
 				player_edit = 0;
 			} else if (key == SDLK_BACKSPACE && strlen(player_name[player_edit-1]) > 0) {
 				player_name[player_edit-1][strlen(player_name[player_edit-1])-1] = 0;
@@ -445,7 +461,7 @@ choose_again:
 				key += 'A' - 'a';
 			}
 
-			if (key == SDLK_RETURN) {
+			if (key == SDLK_RETURN || key == SDLK_KP_ENTER || key == SDLK_ESCAPE) {
 				gamename_edit = 0;
 			} else if (key == SDLK_BACKSPACE && strlen(gamename) > 0) {
 				gamename[strlen(gamename)-1] = 0;
@@ -493,8 +509,10 @@ choose_again:
 			if (IN_PLAYERNAME(i,x,y)) {
 				if (!(network_join || network_create) || player_type[i - 1] == INPUT_LOCAL) {
 					player_edit = i;
+#ifndef MAEMO
 					if (!strncmp(player_name[i-1],get_msg(M_PLAYER), strlen(get_msg(M_PLAYER))))
 						strcpy(player_name[i-1],"");
+#endif
 				}
 			}
 			if (IN_PLAYERTYPE(i,x,y) && !(network_join || network_create)) {
@@ -510,8 +528,10 @@ choose_again:
 		if (IN_GAMENAME(x,y)) {
 			if (gamename) {
 				gamename_edit = TRUE;
+#ifndef MAEMO
 				if (!strcmp(gamename, get_msg(M_NEWGAME)))
 					strcpy(gamename,"");
+#endif
 			}
 		}
 		
