@@ -1,6 +1,6 @@
 /*
  * Biloba
- * Copyright (C) 2004-2005 Guillaume Demougeot, Colin Leroy
+ * Copyright (C) 2004-2008 Guillaume Demougeot, Colin Leroy
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -280,10 +280,10 @@ static void player_kill(Player *player)
 		strcpy(msg, player->name);
 		strcat(msg, get_msg(M_LEAVES));
 	}
-	clear_text(20/* max len, probably */, 20 + 50, YS - 50);
-	draw_message(msg, 20 + 50, YS - 50, FALSE);
+	clear_text(20/* max len, probably */, G_MSG_X, G_MSG_Y);
+	draw_message(msg, G_MSG_X, G_MSG_Y, FALSE);
 	SDL_Delay(1500);	
-	clear_text(strlen(msg), 20 + 50, YS - 50);
+	clear_text(strlen(msg), G_MSG_X, G_MSG_Y);
 	free(msg);	
 }
 
