@@ -1,6 +1,6 @@
 /*
  * Biloba
- * Copyright (C) 2004-2005 Guillaume Demougeot, Colin Leroy
+ * Copyright (C) 2004-2008 Guillaume Demougeot, Colin Leroy
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,6 +34,7 @@
 #include <arpa/inet.h>
 #include <pthread.h>
 #include <time.h>
+#include <signal.h>
 #include "netops.h"
 #include "llist.h"
 #include "game.h"
@@ -62,12 +63,12 @@ pthread_mutex_t gamelist_mutex;
 LList *gamelist = NULL;
 
 #define LOCK_MUTEX() { \
-	fprintf(logfp, "locking mutex from " __FUNCTION__":%d\n", __LINE__); \
+	fprintf(logfp, "locking mutex from %d\n", __LINE__); \
 	fflush(logfp); \
 	pthread_mutex_lock(&gamelist_mutex); \
 }
 #define UNLOCK_MUTEX() { \
-	fprintf(logfp, "unlocking mutex from " __FUNCTION__":%d\n", __LINE__); \
+	fprintf(logfp, "unlocking mutex from %d\n", __LINE__); \
 	fflush(logfp); \
 	pthread_mutex_unlock(&gamelist_mutex); \
 }
@@ -138,9 +139,14 @@ static int get_waiting_players(Game *game)
 	return r;
 }
 
+typedef struct _ConnData {
+	int fd;
+} ConnData;
+
 static void *handleconn(void *data)
 {
-	int myfd = (int)data;
+	ConnData *cd = (ConnData *)data;
+	int myfd = cd->fd;
 	char buf[255];
 	unsigned char len = 0, i;
 	int numplayers = 0;
@@ -151,15 +157,28 @@ static void *handleconn(void *data)
 	int sent_start = 0;
 	char server = '?';
 	int my_move_id = 0;
+	struct timeval timeo;
+
+	free(cd);
 
-	
 	fprintf(logfp, "accepted connection %d\n",myfd);
 	fflush(logfp);
 	/* init connection */
+
+	timeo.tv_sec = 10;
+	timeo.tv_usec = 1;
+	if (setsockopt(myfd, SOL_SOCKET, SO_RCVTIMEO, &timeo, sizeof(timeo)) < 0)
+		perror("setsockopt");
+
 	if (read_msg(myfd, buf, 255, &len) < 0)
 		goto endme;
 	buf[254] = '\0';
 	
+	timeo.tv_sec = 500;
+	timeo.tv_usec = 0;
+	if (setsockopt(myfd, SOL_SOCKET, SO_RCVTIMEO, &timeo, sizeof(timeo)) < 0)
+		perror("setsockopt");
+
 	fprintf(logfp, "MSGTYPE:      got %d bytes: %s\n", len, buf);
 	fflush(logfp);
 	
@@ -795,11 +814,12 @@ endme:
 int main(int argc, char *argv[])
 {
 	int portno = 8000;
-	int sockfd, clifd, clilen;
+	int sockfd, clifd;
+	unsigned int clilen;
 	struct sockaddr_in serv_addr, cli_addr;
 	pthread_t threadid;
 	int optOn = 1;
-
+	
 	if (argc > 1) {
 		logfp = fopen(argv[1], "wb");
 		if (logfp == NULL) {
@@ -834,13 +854,15 @@ int main(int argc, char *argv[])
 	while ((clifd = accept(sockfd,
 			      (struct sockaddr *)&cli_addr,
 			      &clilen)) >= 0) {
+		ConnData *cd = malloc(sizeof(ConnData));
+		
 		setsockopt(clifd, SOL_SOCKET, SO_REUSEADDR,
 			&optOn, sizeof(optOn));
 		
-		
+		cd->fd = clifd;
 		fprintf(logfp, "New connection from %s\n",
 				inet_ntoa(cli_addr.sin_addr));
-		pthread_create(&threadid, NULL, handleconn, (void *)clifd);
+		pthread_create(&threadid, NULL, handleconn, (void *)cd);
 		pthread_detach(threadid);
 
 		clilen = sizeof(cli_addr);	      
