@@ -1,6 +1,6 @@
 /*
  * Biloba
- * Copyright (C) 2004-2005 Guillaume Demougeot, Colin Leroy
+ * Copyright (C) 2004-2008 Guillaume Demougeot, Colin Leroy
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -106,4 +106,9 @@ SDL_Event get_sdl_event(int event_type);
 SDL_Surface *biloba_load_image(const char *name);
 
 void set_language(void);
+
+#ifdef MAEMO
+void SetWMName(const char *name, int is_fullscreen);
+#endif
+
 #endif 
